@@ -7,10 +7,6 @@
  *
  */
 
-#ifndef COPY_C
-#define COPY_C
-#endif
-
 /* Description */
 /*
  * This module contains functions used to copy files to and from an ext2fs
@@ -106,14 +102,8 @@ typedef struct
 elist_t *link_list = NULL;
 static char cur_out_dir[BUF_SIZE];
 
-/* External Prototypes */
-
-extern void init_progress(char *file, struct stat *sbuf);
-
 /* Local Prototypes */
 
-long
-copy(int argc, char *argv[]);
 long
 open_destination(char **dest_dir, char **cur_filesys, ext2_filsys *fs,
                  ext2_ino_t *root, ext2_ino_t *cwd, char *outfile,
@@ -239,11 +229,10 @@ copy(int argc, char *argv[])
 {
   ext2_filsys fs = NULL;
   ext2_ino_t root;
-  ext2_ino_t orig_cwd;
+  ext2_ino_t orig_cwd = -1;
   ext2_ino_t cwd;
   char tmpbuf[BUF_SIZE];
   char outpath[BUF_SIZE];
-  char *last_filesys = NULL;
   char *cur_filesys = NULL;
   int retval;
   int c;
@@ -251,7 +240,7 @@ copy(int argc, char *argv[])
   char *dest_dir = NULL;
   char *in_file = NULL;
   char *out_file = NULL;
-  int max_out_len;
+  int max_out_len = -1;
   int keep = 0;
   int absolute = 0;
   int verbose = 0;
@@ -970,11 +959,11 @@ copy_files(int num_files, char **cur_file_names, char *dest_dir, char *dest_fs,
 static char *
 diag_output_name(char *odir, int file_to_file, char *ofile)
 {
-  static char tmpstr[BUF_SIZE];
+  static char tmpstr[BUF_SIZE+128];
   if (file_to_file)
     {
-      snprintf(tmpstr, BUF_SIZE, "%s/%s", odir, ofile);
-      tmpstr[BUF_SIZE-1] = '\0';
+      snprintf(tmpstr, BUF_SIZE+128, "%s/%s", odir, ofile);
+      tmpstr[BUF_SIZE+128-1] = '\0';
       return(tmpstr);
     }
   else
@@ -1054,7 +1043,6 @@ read_string(char *inbuf)
   char *ptr;
   char *boundary;
   int c;
-  int cnt;
 
   boundary = inbuf + BUF_SIZE - 1;
   ptr = inbuf;
