@@ -44,6 +44,8 @@
 #include "e2tools.h"
 #include "elist.h"
 #include <regex.h>
+#include <stdint.h>
+#include <inttypes.h>
 
 /*
  * list directory
@@ -141,9 +143,9 @@ remove_ls_dups(elist_t *list);
  */
 static int
 list_dir_proc(ext2_ino_t dir, int entry, struct ext2_dir_entry *dirent,
-              int offset, int blocksize, char *buf, void *private)
+              int UNUSED_PARM(offset), int UNUSED_PARM(blocksize),
+	      char UNUSED_PARM(*buf), void *private)
 {
-  struct ext2_inode	inode;
   char			name[EXT2_NAME_LEN];
   struct list_dir_struct *ls = (struct list_dir_struct *) private;
   int thislen;
@@ -485,7 +487,7 @@ do_list_dir(int argc, char *argv[])
       if (ls.options & DELETED_OPT)
         flags |= DIRENT_FLAG_INCLUDE_REMOVED;
             
-      if (retval = ext2fs_check_directory(fs, inode))
+      if ((retval = ext2fs_check_directory(fs, inode)))
         {
         if (retval != EXT2_ET_NO_DIRECTORY)
             {
@@ -618,7 +620,7 @@ do_list_dir(int argc, char *argv[])
  * 04/06/04      K.Sheffield        Modified to show entries with an inode of 0
  *                                  as deleted.
  */
-void long_disp(ls_file_t *info, int *col, int options)
+void long_disp(ls_file_t *info, int UNUSED_PARM(*col), int options)
 {
   char lbr, rbr;
   char datestr[80];
@@ -658,8 +660,8 @@ void long_disp(ls_file_t *info, int *col, int options)
   if (LINUX_S_ISDIR(info->inode.i_mode))
     printf("%7d", info->inode.i_size);
   else
-    printf("%7lld", info->inode.i_size |
-           ((__u64)info->inode.i_size_high << 32));
+    printf("%7" PRIu64, (uint64_t)(info->inode.i_size |
+				  ((__u64)info->inode.i_size_high << 32)));
   printf(" %s %s\n", datestr, info->name);
 
 } /* end of long_disp */ 
@@ -703,7 +705,7 @@ void short_disp(ls_file_t *info, int *col, int options)
   char lbr, rbr;
   char tmp[300];
   int thislen;
-  static max_col_size = 0;
+  static int max_col_size = 0;
 
   if (max_col_size == 0)
     {
@@ -888,7 +890,7 @@ int inode_sort(void *n1, void *n2)
   
   return((retval = (f1->dir - f2->dir)) ? retval :
          ((retval = (f1->type - f2->type)) ? retval :
-          (f1->inode_num - f2->inode_num)));
+          (int)(f1->inode_num - f2->inode_num)));
 } /* end of inode_sort */ 
 
 /* Name:	mod_time_sort()
@@ -933,7 +935,7 @@ int mod_time_sort(void *n1, void *n2)
   
   return((retval = (f1->dir - f2->dir)) ? retval :
          ((retval = (f1->type - f2->type)) ? retval :
-          (f2->inode.i_mtime - f1->inode.i_mtime)));
+          (int)(f2->inode.i_mtime - f1->inode.i_mtime)));
   
 } /* end of mod_time_sort */
 
@@ -979,7 +981,7 @@ int creat_time_sort(void *n1, void *n2)
   
   return((retval = (f1->dir - f2->dir)) ? retval :
          ((retval = (f1->type - f2->type)) ? retval :
-          (f2->inode.i_ctime - f1->inode.i_ctime)));
+          (int)(f2->inode.i_ctime - f1->inode.i_ctime)));
 } /* end of creat_time_sort */ 
 
 /* Name:	remove_ls_dups()
@@ -1023,9 +1025,7 @@ int creat_time_sort(void *n1, void *n2)
 elist_t * remove_ls_dups(elist_t *list)
 {
   elist_t *start = list;
-  elist_t *next;
   ls_file_t *cd;
-  ls_file_t *nd;
   int cnt=0;
 
   while(list != NULL)
